@@ -16,6 +16,7 @@ import (
 
 	"github.com/dundee/gdu/v5/build"
 	"github.com/dundee/gdu/v5/internal/common"
+	"github.com/dundee/gdu/v5/pkg/analyze"
 	"github.com/dundee/gdu/v5/pkg/device"
 	gfs "github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/dundee/gdu/v5/report"
@@ -30,11 +31,13 @@ type UI interface {
 	ListDevices(getter device.DevicesInfoGetter) error
 	AnalyzePath(path string, parentDir gfs.Item) error
 	ReadAnalysis(input io.Reader) error
+	ReadFromStorage(storagePath, path string) error
 	SetIgnoreDirPaths(paths []string)
 	SetIgnoreDirPatterns(paths []string) error
 	SetIgnoreFromFile(ignoreFile string) error
 	SetIgnoreHidden(value bool)
 	SetFollowSymlinks(value bool)
+	SetAnalyzer(analyzer common.Analyzer)
 	StartUILoop() error
 }
 
@@ -61,6 +64,9 @@ type Flags struct {
 	FollowSymlinks    bool     `yaml:"follow-symlinks"`
 	Profiling         bool     `yaml:"profiling"`
 	ConstGC           bool     `yaml:"const-gc"`
+	UseStorage        bool     `yaml:"use-storage"`
+	StoragePath       string   `yaml:"storage-path"`
+	ReadFromStorage   bool     `yaml:"read-from-storage"`
 	Summarize         bool     `yaml:"summarize"`
 	UseSIPrefix       bool     `yaml:"use-si-prefix"`
 	NoPrefix          bool     `yaml:"no-prefix"`
@@ -135,6 +141,12 @@ func (a *App) Run() (err error) {
 		return
 	}
 
+	if a.Flags.UseStorage {
+		ui.SetAnalyzer(analyze.CreateStoredAnalyzer(a.Flags.StoragePath))
+	}
+	if a.Flags.FollowSymlinks {
+		ui.SetFollowSymlinks(true)
+	}
 	if err = a.setNoCross(path); err != nil {
 		return
 	}
@@ -273,10 +285,6 @@ func (a *App) createUI() (UI, error) {
 		tview.Styles.BorderColor = tcell.ColorDefault
 	}
 
-	if a.Flags.FollowSymlinks {
-		ui.SetFollowSymlinks(true)
-	}
-
 	return ui, nil
 }
 
@@ -324,6 +332,11 @@ func (a *App) runAction(ui UI, path string) error {
 		if err := ui.ReadAnalysis(input); err != nil {
 			return fmt.Errorf("reading analysis: %w", err)
 		}
+	} else if a.Flags.ReadFromStorage {
+		ui.SetAnalyzer(analyze.CreateStoredAnalyzer(a.Flags.StoragePath))
+		if err := ui.ReadFromStorage(a.Flags.StoragePath, path); err != nil {
+			return fmt.Errorf("reading from storage (%s): %w", a.Flags.StoragePath, err)
+		}
 	} else {
 		if build.RootPathPrefix != "" {
 			path = build.RootPathPrefix + path
