@@ -17,6 +17,7 @@ const helpText = `     [::b]up/down, k/j    [white:black:-]Move cursor up/down
          [::b]left, h     [white:black:-]Go to parent directory
 
                [::b]r     [white:black:-]Rescan current directory
+               [::b]E     [white:black:-]Export analysis data to file as JSON
                [::b]/     [white:black:-]Search items by name
                [::b]a     [white:black:-]Toggle between showing disk usage and apparent size
                [::b]B     [white:black:-]Toggle bar alignment to biggest file or directory
@@ -188,7 +189,7 @@ func (ui *UI) showDevices() {
 		ui.table.SetCell(i+1, 2, tview.NewTableCell(sizeColor+ui.formatSize(device.Size-device.Free, false, true)))
 		ui.table.SetCell(i+1, 3, tview.NewTableCell(getDeviceUsagePart(device, ui.useOldSizeBar)))
 		ui.table.SetCell(i+1, 4, tview.NewTableCell(ui.formatSize(device.Free, false, true)))
-		ui.table.SetCell(i+1, 5, tview.NewTableCell(textColor+device.MountPoint))
+		ui.table.SetCell(i+1, 5, tview.NewTableCell(textColor+device.MountPoint).SetReference(ui.devices[i]))
 	}
 
 	var footerNumberColor, footerTextColor string
@@ -233,6 +234,13 @@ func (ui *UI) showErr(msg string, err error) {
 	}
 
 	ui.pages.AddPage("error", modal, true, true)
+	ui.app.SetFocus(modal)
+}
+
+func (ui *UI) showErrFromGo(msg string, err error) {
+	ui.app.QueueUpdateDraw(func() {
+		ui.showErr(msg, err)
+	})
 }
 
 func (ui *UI) showHelp() {
