@@ -56,6 +56,7 @@ type UI struct {
 	defaultSortBy           string
 	defaultSortOrder        string
 	markedRows              map[int]struct{}
+	exportName              string
 }
 
 // Option is optional function customizing the bahaviour of UI
@@ -97,6 +98,7 @@ func CreateUI(
 		defaultSortBy:           "size",
 		defaultSortOrder:        "desc",
 		markedRows:              make(map[int]struct{}),
+		exportName:              "export.json",
 	}
 	for _, o := range opts {
 		o(ui)
@@ -132,6 +134,7 @@ func CreateUI(
 
 	ui.table = tview.NewTable().SetSelectable(true, false)
 	ui.table.SetBackgroundColor(tcell.ColorDefault)
+	ui.table.SetSelectedFunc(ui.fileItemSelected)
 
 	if ui.UseColors {
 
@@ -215,15 +218,22 @@ func (ui *UI) rescanDir() {
 
 func (ui *UI) fileItemSelected(row, column int) {
 	if ui.currentDir == nil {
+		return // Add this check to handle nil case
+	}
+
+	selectedDirCell := ui.table.GetCell(row, column)
+
+	// Check if the selectedDirCell is nil before using it
+	if selectedDirCell == nil || selectedDirCell.GetReference() == nil {
+		return
+	}
+
+	selectedDir := selectedDirCell.GetReference().(fs.Item)
+	if selectedDir == nil || !selectedDir.IsDir() {
 		return
 	}
 
 	origDir := ui.currentDir
-	selectedDir := ui.table.GetCell(row, column).GetReference().(fs.Item)
-	if !selectedDir.IsDir() {
-		return
-	}
-
 	ui.currentDir = selectedDir
 	ui.hideFilterInput()
 	ui.markedRows = make(map[int]struct{})
@@ -245,7 +255,10 @@ func (ui *UI) fileItemSelected(row, column int) {
 
 func (ui *UI) deviceItemSelected(row, column int) {
 	var err error
-	selectedDevice := ui.table.GetCell(row, column).GetReference().(*device.Device)
+	selectedDevice, ok := ui.table.GetCell(row, column).GetReference().(*device.Device)
+	if !ok {
+		return
+	}
 
 	paths := device.GetNestedMountpointsPaths(selectedDevice.MountPoint, ui.devices)
 	ui.IgnoreDirPathPatterns, err = common.CreateIgnorePattern(paths)
